#
# spec file for package thunar-volman
#
# Copyright (c) 2020-2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           thunar-volman
Version:        4.20.0
Release:        1.2
Summary:        Thunar Volume Manager
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://goodies.xfce.org/projects/thunar-plugins/thunar-volman
Source0:        https://archive.xfce.org/src/xfce/thunar-volman/4.20/%{name}-%{version}.tar.bz2
Source1:        thunar-volman.xml
# PATCH-FIX-OPENSUSE thunar-volman-use-udisks-hints.diff bnc#949808 -- seife+dev@b1-systems.com
Patch0:         thunar-volman-use-udisks-hints.diff
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(exo-2) >= 0.10.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gudev-1.0) >= 145
BuildRequires:  pkgconfig(libnotify) >= 0.7.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.16.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.12.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Recommends:     %{name}-lang = %{version}

%description
The Thunar Volume Manager is an extension for the Thunar file manager,
which enables automatic management of removable drives and media. For
example, if thunar-volman is installed and configured properly, and you
plug in your digital camera, it will automatically launch your
preferred photo application and import the new pictures from the camera
into your photo collection.

%package branding-upstream
Summary:        Upstream Branding of thunar-volman
Group:          System/GUI/XFCE
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
#BRAND: xfce4.xml: Determines a whether to automatically mount hotpluggable
#BRAND: drives and removable median and whether to open what applications
#BRAND: automatically.
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for the Thunar Volume Manager.

%lang_package

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure --enable-maintainer-mode
%else
%configure
%endif
%make_build

%install
%make_install

install -D -p -m 644 %{SOURCE1} \
    %{buildroot}%{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/thunar-volman.xml

%suse_update_desktop_file thunar-volman-settings Settings DesktopSettings

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS NEWS README.md THANKS
%license COPYING
%{_bindir}/thunar-volman
%{_bindir}/thunar-volman-settings
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/*/*

%files lang -f %{name}.lang

%files branding-upstream
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/thunar-volman.xml

%changelog
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0:
  * Translation Updates
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.1 [development release]:
  * Translation Updates
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.0 [development release]:
  * build: Fix deprecation warning
  * build: Bump requirements for Xfce 4.20
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * README: correct documentation URL
  * settings: make `option_entries` NULL-terminated
  * tvm-input-device: Avoid criticals when ID_MODEL missing (#25)
  * I18n: Update po/LINGUAS list
  * build: Get rid of intltool
  * Add icons at missing sizes, clean up SVG metadata
  * Declare use of function (fixes #24)
  * settings: Fix critical warning when closing embedded dialog
  * Update bug report address
  * Translation Updates
* Wed Dec 21 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0:
  * Bump build requirements for Xfce 4.18.0
- Update to 4.17.1:
  * bump copyright year
  * Drop subtitle from settings dialog
- Update to 4.17.0:
  * autoconf: Use AC_CONFIG_MACRO_DIRS
  * build: Fix intltool lock file problem during make distcheck
  * Update COPYING
  * Fix compilation warnings
  * automake: Enable subdir-objects
  * autoconf: Some updates
  * Update `.gitignore`
  * Replace ExoBinding with GBinding
  * Remove GSourceFunc casts (!5)
  * Translation Updates:
    Arabic, Belarusian, Catalan, Croatian, Czech, Estonian, Galician,
    Greek, Hebrew, Hindi, Norwegian Bokmål, Occitan (post 1500),
    Romanian, Russian, Spanish, Turkish
* Thu Jan  7 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed wrong source URL
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  * Remove GLIB_CHECK_VERSION IFDEFs which are obsolete after glib bump
  * bump glib (and gio, gthread, etc) minimum to 2.50.0
  * Add README.md to EXTRA_DIST
  * Translation Updates
* Mon Nov  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.1
  * Fix typo in README
  * Adds new README.md updates AM_INIT_AUTOMAKE
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.0
  * Use icons from icon theme in the dialog (!3)
  * Add new app icon and switch to rDNS
  * Remove PDA tab (!1)
  * Avoid critical error when closing preferences dialog
  * Support libxfce4ui XfceTitledDialog new API
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.9.5
  * Translation updates
* Sun Jul 28 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.9.4
  * Translation updates
- Added bcond to build with git master source
* Mon Jul  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Remove unneded V=1 flag
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.9.3
  * Removed # vi:set encoding=UTF-8: from .desktop files (bxo#15466)
  * Translation updates
- Removed deprecated macros
* Mon May 20 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 0.9.2
  - Translation updates
* Wed Jan  2 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to version 0.9.1
  - Allow compilation against libxfce4ui 4.12 (bxo#14100)
  - Use transient notifications
  - Visual improvements (bxo#14650)
  - Add support for Blu-ray media (bxo#13297)
  - Relicense tvm-burn-cd.svg (bxo#11204)
  - Autobrowse of removable media opens Thunar, not the user-selected file
    manager (bxo#9537)
  - Translation updates
- Remove obsolete patch thunar-volman-0.9-fix-build-with-xfce-4.12.patch
* Fri Jun 15 2018 seife+obs@b1-systems.com
- update to version 0.9.0
  - GTK3 Port
  - Translation updates
- add thunar-volman-0.9-fix-build-with-xfce-4.12.patch
* Sun Nov 19 2017 seife+obs@b1-systems.com
- add thunar-volman-use-udisks-hints.diff (bnc#949808)
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.8.1
  - workaround: Wait 5 second before mounting devices (bxo#9193)
  - use new show help function instead of thunar help (bxo#10204)
  - fix AC_CONFIG_MACRO_DIR warning
  - remove SVN $Id$ and update .gitignore
  - bump autotools versions
  - fix AC_PROG_INTLTOOL warning
  - enable silent rules
  - don't use deprecated API
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 0.8.0
  - translation updates
* Sun Apr 15 2012 gber@opensuse.org
- enable thunar-volman-branding-upstream for all openSUSE versions
* Sat Apr 14 2012 gber@opensuse.org
- update to version 0.7.1
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 0.7.0
  - show in correct settings category
- drop thunar-volman-brp-desktop-friendly-icon.patch, not needed
  any more
* Sat Mar 31 2012 gber@opensuse.org
- update to version 0.6.1
  - do not make icon names translatable
  - auto generate the ChangeLog
  - translation updates
* Tue Mar 27 2012 gber@opensuse.org
- correct dependencies
- specfile cleanup
* Thu Oct 13 2011 gber@opensuse.org
- added thunar-volman-branding-upstream package for >= 12.1
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb 17 2011 gber@opensuse.org
- added thunar-volman-brp-desktop-friendly-icon.patch and copy
  icons over from gnome-icon-them since brp-desktop insists on
  icons being included with the package
* Thu Feb 17 2011 gber@opensuse.org
- removed the actually obsolete thunar-volman-desktop-icon.patch so
  the now correct icon is shown
* Mon Jan 17 2011 gber@opensuse.org
- update to version 0.6.0
  - bugfixes
- rebased thunar-volman-desktop-icon.patch
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Sun Dec 26 2010 gber@opensuse.org
- split off -lang subpackage
- remove unsupported locales
* Fri Dec  3 2010 prusnak@opensuse.org
- updated to 0.5.2
  - Fix incompatibility with the icon naming specification (bug #6786).
  - Fix compilation without libnotify (bug #6607).
  - Add missing shebang to autogen.sh.
  - Add module.xml for cgit.
  - Remove deprecated enocding key from desktop files.
  - Translation updates: Japanese, Kazakh, Finnish, Russian, Italian,
    Portuguese, Galician, French, German, Slovak, Ukrainian, Uyghur,
    Danish, Catalan (Valencian).
- changes from 0.5.1
  - Fix a weird error with g_udev_device_get_devtype().
  - Remove D-Bus dependency.
  - Update dependencies in README.
- changes from 0.5.0
  - Complete rewrite based on udev/GIO instead of HAL.
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 0.3.80
* Tue Dec  4 2007 prusnak@suse.cz
- fixed desktop file
- use %%find_lang macro
* Tue Dec  4 2007 bwalle@suse.de
- update to 0.2.0
  o Properly ignore case looking for VCD, VIDEO_TS and DCIM folders
  o Do not try to automount if the volume does not contain a
    filesystem
  o Install a .desktop file for the thunar-volman preferences
  o Updated and new translations
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/XFCE'
* Thu Feb  8 2007 prusnak@suse.cz
- initial version from BuildService
